summaryrefslogtreecommitdiffstats
path: root/webkit/plugins/ppapi/plugin_delegate.h
diff options
context:
space:
mode:
Diffstat (limited to 'webkit/plugins/ppapi/plugin_delegate.h')
-rw-r--r--webkit/plugins/ppapi/plugin_delegate.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/webkit/plugins/ppapi/plugin_delegate.h b/webkit/plugins/ppapi/plugin_delegate.h
index 212889a..eefb1e6 100644
--- a/webkit/plugins/ppapi/plugin_delegate.h
+++ b/webkit/plugins/ppapi/plugin_delegate.h
@@ -375,8 +375,8 @@ class PluginDelegate {
// Tells the browser that the PDF has an unsupported feature.
virtual void HasUnsupportedFeature() = 0;
- // Tells the browser to bring up SaveAs dialog.
- virtual void SaveAs() = 0;
+ // Tells the browser to bring up SaveAs dialog to save specified URL.
+ virtual void SaveURLAs(const GURL& url) = 0;
// Socket dispatcher for P2P connections. Returns to NULL if P2P API
// is disabled.